pub struct ScaledPpm(/* private fields */);Expand description
A signed frequency adjustment in parts per million with 16 fractional bits.
Zero selects the nominal clock frequency and positive values make the clock
run faster. One raw unit is 2^-16 ppm, giving a range of approximately
-32768 to +32768 ppm.
Implementations