embassy-ptp-driver

Crates

git

Versions

default

Flavors

Timestamp

Struct Timestamp 

pub struct Timestamp { /* private fields */ }
A reading of a PTP hardware clock.

The clock has an arbitrary epoch and drifts with respect to other clocks unless it is actively disciplined. Do not mix this with executor time.

Implementations

Source

impl Timestamp

pub const fn from_seconds_and_nanos(seconds: u32, nanos: u32) -> Self

Construct a timestamp from seconds and nanoseconds.

pub const fn from_seconds_and_quarter_nanos( seconds: u32, quarter_nanos: u32, ) -> Self

Construct a timestamp from seconds and quarter nanoseconds.

pub const fn seconds(&self) -> u32

Get the whole seconds.

pub const fn quarter_nanos(&self) -> u32

Get the fractional quarter nanoseconds within the current second.

pub const fn nanos(&self) -> u32

Get the whole nanoseconds within the current second.