pub struct Timestamp { /* private fields */ }Expand description
A reading of a PTP hardware clock.
The clock has an arbitrary epoch and drifts with respect to other clocks unless it is actively disciplined. Do not mix this with executor time.
Implementations
Sourceimpl Timestamp
impl Timestamp
Sourcepub const fn from_seconds_and_nanos(seconds: u32, nanos: u32) -> Self
pub const fn from_seconds_and_nanos(seconds: u32, nanos: u32) -> Self
Construct a timestamp from seconds and nanoseconds.
Sourcepub const fn from_seconds_and_quarter_nanos(
seconds: u32,
quarter_nanos: u32,
) -> Self
pub const fn from_seconds_and_quarter_nanos( seconds: u32, quarter_nanos: u32, ) -> Self
Construct a timestamp from seconds and quarter nanoseconds.
Sourcepub const fn quarter_nanos(&self) -> u32
pub const fn quarter_nanos(&self) -> u32
Get the fractional quarter nanoseconds within the current second.